PEP: 251 Title: Python 2.2 Release Schedule Version: $Revision$
Last-Modified: $Date$ Author: barry\@python.org (Barry Warsaw),
guido\@python.org (Guido van Rossum) Status: Final Type: Informational
Content-Type: text/x-rst Created: 17-Apr-2001 Python-Version: 2.2
Post-History: 14-Aug-2001

Abstract
========

This document describes the Python 2.2 development and release schedule.
The schedule primarily concerns itself with PEP-sized items. Small bug
fixes and changes will occur up until the first beta release.

The schedule below represents the actual release dates of Python 2.2.
Note that any subsequent maintenance releases of Python 2.2 should be
covered by separate PEPs.

Release Schedule
================

Tentative future release dates. Note that we've slipped this compared to
the schedule posted around the release of 2.2a1.

-   21-Dec-2001: 2.2 \[Released\] (final release)
-   14-Dec-2001: 2.2c1 \[Released\]
-   14-Nov-2001: 2.2b2 \[Released\]
-   19-Oct-2001: 2.2b1 \[Released\]
-   28-Sep-2001: 2.2a4 \[Released\]
-   7-Sep-2001: 2.2a3 \[Released\]
-   22-Aug-2001: 2.2a2 \[Released\]
-   18-Jul-2001: 2.2a1 \[Released\]

Release Manager
===============

Barry Warsaw was the Python 2.2 release manager.

Release Mechanics
=================

We experimented with a new mechanism for releases: a week before every
alpha, beta or other release, we forked off a branch which became the
release. Changes to the branch are limited to the release manager and
his designated 'bots. This experiment was deemed a success and should be
observed for future releases. See PEP 101 for the actual release
mechanics \[1\]\_.

New features for Python 2.2
===========================

The following new features are introduced in Python 2.2. For a more
detailed account, see Misc/NEWS \[2\]\_ in the Python distribution, or
Andrew Kuchling's "What's New in Python 2.2" document \[3\]\_.

-   iterators (PEP 234)
-   generators (PEP 255)
-   unifying long ints and plain ints (PEP 237)
-   division (PEP 238)
-   unification of types and classes (PEP 252, PEP 253)

References
==========

.. \[1\] PEP 101, Doing Python Releases 101
http://www.python.org/dev/peps/pep-0101/

.. \[2\] Misc/NEWS file from CVS
http://cvs.sourceforge.net/cgi-bin/viewcvs.cgi/python/python/dist/src/Misc/NEWS?rev=1.337.2.4&content-type=text/vnd.viewcvs-markup

.. \[3\] Andrew Kuchling, What's New in Python 2.2
http://www.python.org/doc/2.2.1/whatsnew/whatsnew22.html

Copyright
=========

This document has been placed in the public domain.

.. Local Variables: mode: indented-text indent-tabs-mode: nil End:
